@@ -30,6 +30,7 @@ type Model struct {
 	Author   string
 	Date     string
 	Theme    glamour.TermRendererOption
+	Paging   string
 	FileName string
 	viewport viewport.Model
 	// VirtualText is used for additional information that is not part of the
@@ -69,9 +70,10 @@ func (m *Model) Load() error {
 		return err
 	}
 
+	content = strings.TrimPrefix(content, strings.TrimPrefix(delimiter, "\n"))
 	slides := strings.Split(content, delimiter)
 
-	metaData, exists := meta.New().ParseHeader(slides[0])
+	metaData, exists := meta.New().Parse(slides[0])
 	// If the user specifies a custom configuration options
 	// skip the first "slide" since this is all configuration
 	if exists && len(slides) > 1 {
@@ -79,6 +81,9 @@ func (m *Model) Load() error {
 	}
 
 	m.Slides = slides
+	m.Author = metaData.Author
+	m.Date = time.Now().Format(metaData.Date)
+	m.Paging = metaData.Paging
 	if m.Theme == nil {
 		m.Theme = styles.SelectTheme(metaData.Theme)
 	}
@@ -144,11 +149,22 @@ func (m Model) View() string {
 	slide = styles.Slide.Render(slide)
 
 	left := styles.Author.Render(m.Author) + styles.Date.Render(m.Date)
-	right := styles.Page.Render(fmt.Sprintf("Slide %d / %d", m.Page+1, len(m.Slides)))
+	right := styles.Page.Render(m.paging())
 	status := styles.Status.Render(styles.JoinHorizontal(left, right, m.viewport.Width))
 	return styles.JoinVertical(slide, status, m.viewport.Height)
 }
 
+func (m *Model) paging() string {
+	switch strings.Count(m.Paging, "%d") {
+	case 2:
+		return fmt.Sprintf(m.Paging, m.Page+1, len(m.Slides))
+	case 1:
+		return fmt.Sprintf(m.Paging, m.Page+1)
+	default:
+		return m.Paging
+	}
+}
+
 func readFile(path string) (string, error) {
 	s, err := os.Stat(path)
 	if err != nil {
@@ -166,6 +182,11 @@ func readFile(path string) (string, error) {
 	// Pre-process slides if the file is executable to avoid
 	// unintentional code execution when presenting slides
 	if file.IsExecutable(s) {
+		// Remove shebang if file has one
+		if strings.HasPrefix(content, "#!") {
+			content = strings.Join(strings.SplitN(content, "\n", 2)[1:], "\n")
+		}
+
 		content = process.Pre(content)
 	}
 
